@@ -168,12 +168,6 @@ WidgetClass formWidgetClass = (WidgetClass)&formClassRec;
 static XrmQuark	XtQChainLeft, XtQChainRight, XtQChainTop,
 		XtQChainBottom, XtQRubber;
 
-#define	done(address, type) \
-	{ toVal->size = sizeof(type); \
-	  toVal->addr = (XPointer) address; \
-	  return; \
-	}
-
 /* ARGSUSED */
 static void _CvtStringToEdgeType(args, num_args, fromVal, toVal)
     XrmValuePtr args;		/* unused */
@@ -181,36 +175,29 @@ static void _CvtStringToEdgeType(args, num_args, fromVal, toVal)
     XrmValuePtr fromVal;
     XrmValuePtr toVal;
 {
-    static XtEdgeType edgeType;
-    XrmQuark q;
-    char lowerName[1000];
+  static XtEdgeType edgeType;
+  XrmQuark q;
+  char lowerName[40];
 
+  if (strlen ((char*) fromVal->addr) < sizeof lowerName) {
     XmuCopyISOLatin1Lowered (lowerName, (char*)fromVal->addr);
     q = XrmStringToQuark(lowerName);
-    if (q == XtQChainLeft) {
-	edgeType = XtChainLeft;
-	done(&edgeType, XtEdgeType);
+    if (q == XtQChainLeft)        edgeType = XtChainLeft;
+    else if (q == XtQChainRight)  edgeType = XtChainRight;
+    else if (q == XtQChainTop)    edgeType = XtChainTop;
+    else if (q == XtQChainBottom) edgeType = XtChainBottom;
+    else if (q == XtQRubber)      edgeType = XtRubber;
+    else {
+      toVal->size = 0;
+      toVal->addr = NULL;
+      return;
     }
-    if (q == XtQChainRight) {
-	edgeType = XtChainRight;
-	done(&edgeType, XtEdgeType);
-    }
-    if (q == XtQChainTop) {
-	edgeType = XtChainTop;
-	done(&edgeType, XtEdgeType);
-	/* NOTREACHED */
-    }
-    if (q == XtQChainBottom) {
-	edgeType = XtChainBottom;
-	done(&edgeType, XtEdgeType);
-    }
-    if (q == XtQRubber) {
-	edgeType = XtRubber;
-	done(&edgeType, XtEdgeType);
-    }
-    XtStringConversionWarning(fromVal->addr, "edgeType");
-    toVal->addr = NULL;
-    toVal->size = 0;
+    toVal->size = sizeof edgeType;
+    toVal->addr = (XPointer) &edgeType;
+    return;
+  }
+  toVal->addr = NULL;
+  toVal->size = 0;
 }
 
 static void ClassInitialize()
