@@ -1433,20 +1433,28 @@ CvtStringToMultiType(args, num_args, fromVal, toVal)
   static XrmQuark  XtQEstring = NULLQUARK;
   static XrmQuark  XtQEfile;
   XrmQuark q;
-  char lowerName[BUFSIZ];
+  char lowerName[40];
 
   if (XtQEstring == NULLQUARK) {
     XtQEstring = XrmPermStringToQuark(XtEstring);
     XtQEfile   = XrmPermStringToQuark(XtEfile);
   }
 
-  XmuCopyISOLatin1Lowered(lowerName, (char *) fromVal->addr);
-  q = XrmStringToQuark(lowerName);
+  if (strlen ((char*) fromVal->addr) < sizeof lowerName) {
+    XmuCopyISOLatin1Lowered(lowerName, (char *) fromVal->addr);
+    q = XrmStringToQuark(lowerName);
 
-  if (q == XtQEstring) type = XawAsciiString;
-  if (q == XtQEfile)  type = XawAsciiFile;
-
-  (*toVal).size = sizeof(XawAsciiType);
-  (*toVal).addr = (XPointer) &type;
-  return;
+    if (q == XtQEstring)     type = XawAsciiString;
+    else if (q == XtQEfile)  type = XawAsciiFile;
+    else {
+      toVal->size = 0;
+      toVal->addr = NULL;
+      return;
+    }
+    toVal->size = sizeof type;
+    toVal->addr = (XPointer) &type;
+    return;
+  }
+  toVal->size = 0;
+  toVal->addr = NULL;
 }
