@@ -299,9 +299,6 @@ Atom selection;
 }
 
 
-#define done(address, type) \
-        { toVal->size = sizeof(type); toVal->addr = (XPointer) address; }
-
 /* ARGSUSED */
 static void 
 CvtStringToEditMode(args, num_args, fromVal, toVal)
@@ -313,7 +310,7 @@ XrmValuePtr	toVal;
   static XawTextEditType editType;
   static  XrmQuark  QRead, QAppend, QEdit;
   XrmQuark    q;
-  char        lowerName[BUFSIZ];
+  char        lowerName[40];
   static Boolean inited = FALSE;
     
   if ( !inited ) {
@@ -323,18 +320,24 @@ XrmValuePtr	toVal;
     inited = TRUE;
   }
 
-  XmuCopyISOLatin1Lowered (lowerName, (char *)fromVal->addr);
-  q = XrmStringToQuark(lowerName);
+  if (strlen ((char*) fromVal->addr) < sizeof lowerName) {
+    XmuCopyISOLatin1Lowered (lowerName, (char *)fromVal->addr);
+    q = XrmStringToQuark(lowerName);
 
-  if       (q == QRead)          editType = XawtextRead;
-  else if (q == QAppend)         editType = XawtextAppend;
-  else if (q == QEdit)           editType = XawtextEdit;
-  else {
-    done(NULL, 0);
+    if      (q == QRead)   editType = XawtextRead;
+    else if (q == QAppend) editType = XawtextAppend;
+    else if (q == QEdit)   editType = XawtextEdit;
+    else {
+      toVal->size = 0;
+      toVal->addr = NULL;
+      return;
+    }
+    toVal->size = sizeof editType;
+    toVal->addr = (XPointer) &editType;
     return;
   }
-  done(&editType, XawTextEditType);
-  return;
+  toVal->size = 0;
+  toVal->addr = NULL;
 }
 
 
